#
# PySNMP MIB module WWW-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/WWW-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:33:08 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueRangeConstraint")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( Bits, TimeTicks, ObjectIdentity, Counter32, Counter64, MibIdentifier, IpAddress, ModuleIdentity, Unsigned32, iso, Gauge32, Integer32, NotificationType, mib_2, MibScalar, MibTable, MibTableRow, MibTableColumn, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Bits", "TimeTicks", "ObjectIdentity", "Counter32", "Counter64", "MibIdentifier", "IpAddress", "ModuleIdentity", "Unsigned32", "iso", "Gauge32", "Integer32", "NotificationType", "mib-2", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn")
( DateAndTime, TimeInterval, TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "DateAndTime", "TimeInterval", "TextualConvention", "DisplayString")
( Utf8String, ) = mibBuilder.importSymbols("SYSAPPL-MIB", "Utf8String")
wwwMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 65)).setRevisions(("1999-02-25 14:00",))
if mibBuilder.loadTexts: wwwMIB.setLastUpdated('9902251400Z')
if mibBuilder.loadTexts: wwwMIB.setOrganization('IETF Application MIB Working Group')
if mibBuilder.loadTexts: wwwMIB.setContactInfo('        Harrie Hazewinkel\n\n            Postal: Joint Research Centre of the E.C.\n                    via Fermi - Ispra 21020 (VA)\n                    Italy\n\n               Tel: +39+(0)332 786322\n               Fax: +39+(0)332 785641\n            E-mail: harrie.hazewinkel@jrc.it\n\n                    Carl W. Kalbfleisch\n\n            Postal: Verio, Inc.\n                    1950 Stemmons Freeway\n                    Suite 2006\n                    Dallas, TX 75207\n                    US\n\n               Tel: +1 214 290-8653\n               Fax: +1 214 744-0742\n            E-mail: cwk@verio.net\n\n                    Juergen Schoenwaelder\n\n            Postal: TU Braunschweig\n                    Bueltenweg 74/75\n                    38106 Braunschweig\n                    Germany\n\n               Tel: +49 531 391-3683\n               Fax: +49 531 489-5936\n            E-mail: schoenw@ibr.cs.tu-bs.de')
if mibBuilder.loadTexts: wwwMIB.setDescription("This WWW service MIB module is applicable to services\n            realized by a family of 'Document Transfer Protocols'\n            (DTP). Examples of DTPs are HTTP and FTP.")
wwwMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 65, 1))
wwwMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 65, 2))
class WwwRequestType(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(1,40)

class WwwResponseType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,2147483647)

class WwwOperStatus(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))
    namedValues = NamedValues(("down", 1), ("running", 2), ("halted", 3), ("congested", 4), ("restarting", 5),)

class WwwDocName(OctetString, TextualConvention):
    displayHint = '255a'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,255)

wwwService = MibIdentifier((1, 3, 6, 1, 2, 1, 65, 1, 1))
wwwServiceTable = MibTable((1, 3, 6, 1, 2, 1, 65, 1, 1, 1), )
if mibBuilder.loadTexts: wwwServiceTable.setDescription('The table of the WWW services known by the SNMP agent.')
wwwServiceEntry = MibTableRow((1, 3, 6, 1, 2, 1, 65, 1, 1, 1, 1), ).setIndexNames((0, "WWW-MIB", "wwwServiceIndex"))
if mibBuilder.loadTexts: wwwServiceEntry.setDescription('Details about a particular WWW service.')
wwwServiceIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 1, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: wwwServiceIndex.setDescription('An integer used to uniquely identify a WWW service. The\n            value must be the same as the corresponding value of the\n            applSrvIndex defined in the Application Management MIB\n            (APPLICATION-MIB) if the applSrvIndex object is available.\n            It might be necessary to manually configure sub-agents in\n            order to meet this requirement.')
wwwServiceDescription = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 1, 1, 1, 2), Utf8String()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwServiceDescription.setDescription('Textual description of the WWW service. This shall include\n            at least the vendor and version number of the application\n            realizing the WWW service. In a minimal case, this might\n            be the Product Token (see RFC 2068) for the application.')
wwwServiceContact = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 1, 1, 1, 3), Utf8String()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwServiceContact.setDescription("The textual identification of the contact person for this\n            service, together with information on how to contact this\n            person. For instance, this might be a string containing an\n            email address, e.g. '<webmaster@domain.name>'.")
wwwServiceProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 1, 1, 1, 4), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwServiceProtocol.setDescription("An identification of the primary protocol in use by this\n            service. For Internet applications, the IANA maintains\n            a registry of the OIDs which correspond to well-known\n            application protocols.  If the application protocol is not\n            listed in the registry, an OID value of the form\n            {applTCPProtoID port} or {applUDPProtoID port} are used for\n            TCP-based and UDP-based protocols, respectively. In either\n            case 'port' corresponds to the primary port number being\n            used by the protocol.")
wwwServiceName = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 1, 1, 1, 5), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwServiceName.setDescription('The fully qualified domain name by which this service is\n            known. This object must contain the virtual host name if\n            the service is realized for a virtual host.')
wwwServiceType = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 1, 1, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("wwwOther", 1), ("wwwServer", 2), ("wwwClient", 3), ("wwwProxy", 4), ("wwwCachingProxy", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwServiceType.setDescription('The application type using or realizing this WWW service.')
wwwServiceStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 1, 1, 1, 7), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwServiceStartTime.setDescription("The date and time when this WWW service was last started.\n            The value SHALL be '0000000000000000'H if the last start\n            time of this WWW service is not known.")
wwwServiceOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 1, 1, 1, 8), WwwOperStatus()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwServiceOperStatus.setDescription('Indicates the operational status of the WWW service.')
wwwServiceLastChange = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 1, 1, 1, 9), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwServiceLastChange.setDescription("The date and time when this WWW service entered its current\n            operational state. The value SHALL be '0000000000000000'H if\n            the time of the last state change is not known.")
wwwProtocolStatistics = MibIdentifier((1, 3, 6, 1, 2, 1, 65, 1, 2))
wwwSummaryTable = MibTable((1, 3, 6, 1, 2, 1, 65, 1, 2, 1), )
if mibBuilder.loadTexts: wwwSummaryTable.setDescription('The table providing overview statistics for the\n            WWW services on this system.')
wwwSummaryEntry = MibTableRow((1, 3, 6, 1, 2, 1, 65, 1, 2, 1, 1), ).setIndexNames((0, "WWW-MIB", "wwwServiceIndex"))
if mibBuilder.loadTexts: wwwSummaryEntry.setDescription('Overview statistics for an individual service.')
wwwSummaryInRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 1, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwSummaryInRequests.setDescription('The number of requests successfully received.')
wwwSummaryOutRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwSummaryOutRequests.setDescription('The number of requests generated.')
wwwSummaryInResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwSummaryInResponses.setDescription('The number of responses successfully received.')
wwwSummaryOutResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 1, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwSummaryOutResponses.setDescription('The number of responses generated.')
wwwSummaryInBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 1, 1, 5), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwSummaryInBytes.setDescription('The number of content bytes received.')
wwwSummaryInLowBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwSummaryInLowBytes.setDescription('The lowest thirty-two bits of wwwSummaryInBytes.')
wwwSummaryOutBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 1, 1, 7), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwSummaryOutBytes.setDescription('The number of content bytes transmitted.')
wwwSummaryOutLowBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 1, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwSummaryOutLowBytes.setDescription('The lowest thirty-two bits of wwwSummaryOutBytes.')
wwwRequestInTable = MibTable((1, 3, 6, 1, 2, 1, 65, 1, 2, 2), )
if mibBuilder.loadTexts: wwwRequestInTable.setDescription('The table providing detailed statistics for requests\n            received by WWW services on this system.')
wwwRequestInEntry = MibTableRow((1, 3, 6, 1, 2, 1, 65, 1, 2, 2, 1), ).setIndexNames((0, "WWW-MIB", "wwwServiceIndex"), (0, "WWW-MIB", "wwwRequestInIndex"))
if mibBuilder.loadTexts: wwwRequestInEntry.setDescription('Request statistics for an individual service.')
wwwRequestInIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 2, 1, 1), WwwRequestType())
if mibBuilder.loadTexts: wwwRequestInIndex.setDescription('The particular request type the statistics apply to.')
wwwRequestInRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 2, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwRequestInRequests.setDescription('The number of requests of this type received by this\n            WWW service.')
wwwRequestInBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 2, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwRequestInBytes.setDescription('The number of content bytes per request type received\n            by this WWW service.')
wwwRequestInLastTime = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 2, 1, 4), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwRequestInLastTime.setDescription("The date and time when the last byte of the last complete\n            request of this type was received by this WWW service. The\n            value SHALL be '0000000000000000'H if no request of this\n            type has been received yet.")
wwwRequestOutTable = MibTable((1, 3, 6, 1, 2, 1, 65, 1, 2, 3), )
if mibBuilder.loadTexts: wwwRequestOutTable.setDescription('The table providing detailed statistics for requests\n            generated by the services on this system.')
wwwRequestOutEntry = MibTableRow((1, 3, 6, 1, 2, 1, 65, 1, 2, 3, 1), ).setIndexNames((0, "WWW-MIB", "wwwServiceIndex"), (0, "WWW-MIB", "wwwRequestOutIndex"))
if mibBuilder.loadTexts: wwwRequestOutEntry.setDescription('Request statistics for an individual service.')
wwwRequestOutIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 3, 1, 1), WwwRequestType())
if mibBuilder.loadTexts: wwwRequestOutIndex.setDescription('The particular request type the statistics apply to.')
wwwRequestOutRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 3, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwRequestOutRequests.setDescription('The number of requests of this type generated by this\n            WWW service.')
wwwRequestOutBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 3, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwRequestOutBytes.setDescription('The number of content bytes per requests type generated\n            by this WWW service.')
wwwRequestOutLastTime = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 3, 1, 4), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwRequestOutLastTime.setDescription("The date and time when the first byte of the last request\n            of this type was send by this WWW service. The value SHALL\n            be '0000000000000000'H if no request of this type has been\n            send yet.")
wwwResponseInTable = MibTable((1, 3, 6, 1, 2, 1, 65, 1, 2, 4), )
if mibBuilder.loadTexts: wwwResponseInTable.setDescription('The table providing detailed statistics for responses\n            received by WWW services on this system.')
wwwResponseInEntry = MibTableRow((1, 3, 6, 1, 2, 1, 65, 1, 2, 4, 1), ).setIndexNames((0, "WWW-MIB", "wwwServiceIndex"), (0, "WWW-MIB", "wwwResponseInIndex"))
if mibBuilder.loadTexts: wwwResponseInEntry.setDescription('Response statistics for an individual service.')
wwwResponseInIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 4, 1, 1), WwwResponseType())
if mibBuilder.loadTexts: wwwResponseInIndex.setDescription('The particular response type the statistics apply to.')
wwwResponseInResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 4, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwResponseInResponses.setDescription('The number of responses of this type received by this\n            WWW service.')
wwwResponseInBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 4, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwResponseInBytes.setDescription('The number of content bytes per response type received\n            by this WWW service.')
wwwResponseInLastTime = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 4, 1, 4), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwResponseInLastTime.setDescription("The date and time when the last byte of the last complete\n            response of this type was received by this WWW service. The\n            value SHALL be '0000000000000000'H if no response of this\n            type has been received yet.")
wwwResponseOutTable = MibTable((1, 3, 6, 1, 2, 1, 65, 1, 2, 5), )
if mibBuilder.loadTexts: wwwResponseOutTable.setDescription('The table providing detailed statistics for responses\n            generated by services on this system.')
wwwResponseOutEntry = MibTableRow((1, 3, 6, 1, 2, 1, 65, 1, 2, 5, 1), ).setIndexNames((0, "WWW-MIB", "wwwServiceIndex"), (0, "WWW-MIB", "wwwResponseOutIndex"))
if mibBuilder.loadTexts: wwwResponseOutEntry.setDescription('Response statistics for an individual service.')
wwwResponseOutIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 5, 1, 1), WwwResponseType())
if mibBuilder.loadTexts: wwwResponseOutIndex.setDescription('The particular response type the statistics apply to.')
wwwResponseOutResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 5, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwResponseOutResponses.setDescription('The number of responses of this type generated by this\n            WWW service.')
wwwResponseOutBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 5, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwResponseOutBytes.setDescription('The number of content bytes per response type generated\n            by this WWW service.')
wwwResponseOutLastTime = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 2, 5, 1, 4), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwResponseOutLastTime.setDescription("The date and time when the first byte of the last response of\n            this type was sent by this WWW service. The value SHALL be\n            '0000000000000000'H if response of this type has been send\n            yet.")
wwwDocumentStatistics = MibIdentifier((1, 3, 6, 1, 2, 1, 65, 1, 3))
wwwDocCtrlTable = MibTable((1, 3, 6, 1, 2, 1, 65, 1, 3, 1), )
if mibBuilder.loadTexts: wwwDocCtrlTable.setDescription('A table which controls how the MIB implementation\n            collects and maintains document statistics.')
wwwDocCtrlEntry = MibTableRow((1, 3, 6, 1, 2, 1, 65, 1, 3, 1, 1), ).setIndexNames((0, "WWW-MIB", "wwwServiceIndex"))
if mibBuilder.loadTexts: wwwDocCtrlEntry.setDescription('An entry used to configure the wwwDocLastNTable,\n            the wwwDocBucketTable, the wwwDocAccessTopNTable,\n            and the wwwDocBytesTopNTable.')
wwwDocCtrlLastNSize = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 1, 1, 1), Unsigned32().clone(25)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: wwwDocCtrlLastNSize.setDescription('The maximum number of entries in the wwwDocLastNTable.')
wwwDocCtrlLastNLock = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 1, 1, 2), TimeTicks()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: wwwDocCtrlLastNLock.setDescription('This object allows a manager to lock the wwwDocLastNTable\n            in order to retrieve the wwwDocLastNTable in a consistent\n            state. The agent is expected to take a snapshot of the\n            wwwDocLastNTable when it is locked and to continue updating\n            the real wwwDocLastNTable table so that recent information is\n            available as soon as the wwwDocLastNTable is unlocked again.\n\n            Setting this object to a value greater than 0 will lock\n            the table. The timer ticks backwards until it reaches 0.\n            The table unlocks automatically once the timer reaches 0\n            and the timer stops ticking.\n\n            A manager can increase the timer to request more time to\n            read the table. However, any attempt to decrease the timer\n            will fail with an inconsistentValue error. This rule ensures\n            that multiple managers can simultaneously lock and retrieve\n            the wwwDocLastNTable. Note that managers must cooperate in\n            using wwwDocCtrlLastNLock. In particular, a manager MUST not\n            keep the wwwDocLastNTable locked when it is not necessary to\n            finish a retrieval operation.')
wwwDocCtrlBuckets = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 1, 1, 3), Unsigned32().clone(4)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: wwwDocCtrlBuckets.setDescription('The maximum number of buckets maintained by the agent\n            before the oldest bucket is deleted. The buckets are\n            used to populate the wwwDocAccessTopNTable and the\n            wwwDocBytesTopNTable. The time interval captured in\n            each bucket can be configured by setting the\n            wwwDocCtrlBucketTimeInterval object.')
wwwDocCtrlBucketTimeInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 1, 1, 4), TimeInterval().clone(90000)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: wwwDocCtrlBucketTimeInterval.setDescription('The time interval after which a new bucket is created.\n            Changing this object has no effect on existing buckets.')
wwwDocCtrlTopNSize = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 1, 1, 5), Unsigned32().clone(25)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: wwwDocCtrlTopNSize.setDescription('The maximum number of entries shown in the\n            wwwDocAccessTopNTable and the wwwDocBytesTopNTable.\n            Changing this object has no effect on existing buckets.')
wwwDocLastNTable = MibTable((1, 3, 6, 1, 2, 1, 65, 1, 3, 2), )
if mibBuilder.loadTexts: wwwDocLastNTable.setDescription('The table which logs the last N access attempts.')
wwwDocLastNEntry = MibTableRow((1, 3, 6, 1, 2, 1, 65, 1, 3, 2, 1), ).setIndexNames((0, "WWW-MIB", "wwwServiceIndex"), (0, "WWW-MIB", "wwwDocLastNIndex"))
if mibBuilder.loadTexts: wwwDocLastNEntry.setDescription('An entry which describes a recent access attempt.')
wwwDocLastNIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 2, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: wwwDocLastNIndex.setDescription('An arbitrary monotonically increasing integer number used\n            for indexing the wwwDocLastNTable. The first document\n            accessed appears in the table with this index value equal\n            to one. Each subsequent document is indexed with the next\n            sequential index value. The Nth document accessed will be\n            indexed by N. This table presents a sliding window of the\n            last wwwDocCtrlLastNSize documents accessed. Thus, entries\n            in this table will be indexed by N-wwwDocCtrlLastNSize\n            thru N if N > wwwDocCtrlLastNSize and 1 thru N if\n            N <= wwwDocCtrlLastNSize.\n\n            The wwwDocCtrlLastNLock attribute can be used to lock\n            this table to allow the manager to read its contents.')
wwwDocLastNName = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 2, 1, 2), WwwDocName()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocLastNName.setDescription('The name of the document for which access was attempted.')
wwwDocLastNTimeStamp = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 2, 1, 3), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocLastNTimeStamp.setDescription('The date and time of the last attempt to access this\n            document.')
wwwDocLastNRequestType = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 2, 1, 4), WwwRequestType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocLastNRequestType.setDescription('The protocol request type which was received by the\n            server when this document access was attempted.')
wwwDocLastNResponseType = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 2, 1, 5), WwwResponseType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocLastNResponseType.setDescription('The protocol response type which was sent to the client\n            as a result of this attempt to access a document. This\n            object contains the type of the primary response if\n            there were multiple responses to a single request.')
wwwDocLastNStatusMsg = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 2, 1, 6), Utf8String()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocLastNStatusMsg.setDescription("This object contains a human readable description of the\n            reason why the wwwDocLastNResponseType was returned to the\n            client. This object defines the implementation-specific\n            reason if the value of wwwDocLastNResponseType indicates\n            an error. For example, this object can indicate that the\n            requested document could not be transferred due to a\n            timeout condition or the document could not be transferred\n            because a 'soft link' pointing to the document could not be\n            resolved.")
wwwDocLastNBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 2, 1, 7), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocLastNBytes.setDescription('The number of content bytes that were returned as a\n            result of this attempt to access a document.')
wwwDocBucketTable = MibTable((1, 3, 6, 1, 2, 1, 65, 1, 3, 3), )
if mibBuilder.loadTexts: wwwDocBucketTable.setDescription('This table provides administrative summary information for\n            the buckets maintained per WWW service.')
wwwDocBucketEntry = MibTableRow((1, 3, 6, 1, 2, 1, 65, 1, 3, 3, 1), ).setIndexNames((0, "WWW-MIB", "wwwServiceIndex"), (0, "WWW-MIB", "wwwDocBucketIndex"))
if mibBuilder.loadTexts: wwwDocBucketEntry.setDescription('An entry which describes the parameters associated with a\n            particular bucket.')
wwwDocBucketIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 3, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: wwwDocBucketIndex.setDescription('An arbitrary monotonically increasing integer number\n            used for indexing the wwwDocBucketTable. The index number\n            wraps to 1 whenever the maximum value is reached.')
wwwDocBucketTimeStamp = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 3, 1, 2), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocBucketTimeStamp.setDescription('The date and time when the bucket was made available.')
wwwDocBucketAccesses = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 3, 1, 3), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocBucketAccesses.setDescription('The total number of access attempts for any document\n            provided by this WWW service during the time interval\n            over which this bucket was created.')
wwwDocBucketDocuments = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 3, 1, 4), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocBucketDocuments.setDescription('The total number of different documents for which access\n            was attempted this this WWW service during the time interval\n            over which this bucket was created.')
wwwDocBucketBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 3, 1, 5), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocBucketBytes.setDescription('The total number of content bytes which were transferred\n            from this WWW service during the time interval over which\n            this bucket was created.')
wwwDocAccessTopNTable = MibTable((1, 3, 6, 1, 2, 1, 65, 1, 3, 4), )
if mibBuilder.loadTexts: wwwDocAccessTopNTable.setDescription('The table of the most frequently accessed documents in a\n            given bucket. This table is sorted by the column\n            wwwDocAccessTopNAccesses. Entries having the same number\n            of accesses are secondarily sorted by wwwDocAccessTopNBytes.\n            Entries with the same number of accesses and the same\n            number of bytes will have an arbitrary order.')
wwwDocAccessTopNEntry = MibTableRow((1, 3, 6, 1, 2, 1, 65, 1, 3, 4, 1), ).setIndexNames((0, "WWW-MIB", "wwwServiceIndex"), (0, "WWW-MIB", "wwwDocBucketIndex"), (0, "WWW-MIB", "wwwDocAccessTopNIndex"))
if mibBuilder.loadTexts: wwwDocAccessTopNEntry.setDescription('An entry in the top N table sorted by document accesses.')
wwwDocAccessTopNIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 4, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: wwwDocAccessTopNIndex.setDescription('An arbitrary monotonically increasing integer number\n            used for indexing the wwwDocAccessTopNTable. The index is\n            inversely correlated to the sorting order of the table. The\n            document with the highest access count will get the index\n            value 1.')
wwwDocAccessTopNName = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 4, 1, 2), WwwDocName()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocAccessTopNName.setDescription('The name of the document for which access was attempted.')
wwwDocAccessTopNAccesses = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 4, 1, 3), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocAccessTopNAccesses.setDescription('The total number of access attempts for this document.')
wwwDocAccessTopNBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 4, 1, 4), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocAccessTopNBytes.setDescription('The total number of content bytes that were transmitted\n            as a result of attempts to access this document.')
wwwDocAccessTopNLastResponseType = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 4, 1, 5), WwwResponseType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocAccessTopNLastResponseType.setDescription('The protocol response type which was sent to the client\n            as a result of the last attempt to access this document.\n            This object contains the type of the primary response if\n            there were multiple responses to a single request.')
wwwDocBytesTopNTable = MibTable((1, 3, 6, 1, 2, 1, 65, 1, 3, 5), )
if mibBuilder.loadTexts: wwwDocBytesTopNTable.setDescription('The table of the documents which caused most network\n            traffic in a given bucket. This table is sorted by the\n            column wwwDocBytesTopNBytes. Entries having the same number\n            bytes are secondarily sorted by wwwDocBytesTopNAccesses.\n            Entries with the same number of accesses and the same\n            number of bytes will have an arbitrary order.')
wwwDocBytesTopNEntry = MibTableRow((1, 3, 6, 1, 2, 1, 65, 1, 3, 5, 1), ).setIndexNames((0, "WWW-MIB", "wwwServiceIndex"), (0, "WWW-MIB", "wwwDocBucketIndex"), (0, "WWW-MIB", "wwwDocBytesTopNIndex"))
if mibBuilder.loadTexts: wwwDocBytesTopNEntry.setDescription('An entry in the top N table sorted by network traffic.')
wwwDocBytesTopNIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 5, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: wwwDocBytesTopNIndex.setDescription('An arbitrary monotonically increasing integer number\n            used for indexing the wwwDocBytesTopNTable. The index is\n            inversely correlated to the sorting order of the table. The\n            document with the highest byte count will get the index\n            value 1.')
wwwDocBytesTopNName = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 5, 1, 2), WwwDocName()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocBytesTopNName.setDescription('The name of the document for which access was attempted.')
wwwDocBytesTopNAccesses = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 5, 1, 3), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocBytesTopNAccesses.setDescription('The total number of access attempts for this document.')
wwwDocBytesTopNBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 5, 1, 4), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocBytesTopNBytes.setDescription('The total number of content bytes that were transmitted\n            as a result of attempts to access this document.')
wwwDocBytesTopNLastResponseType = MibTableColumn((1, 3, 6, 1, 2, 1, 65, 1, 3, 5, 1, 5), WwwResponseType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: wwwDocBytesTopNLastResponseType.setDescription('The protocol response type which was sent to the client\n            as a result of the last attempt to access this document.\n            This object contains the type of the primary response if\n            there were multiple responses to a single request.')
wwwMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 65, 2, 1))
wwwMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 65, 2, 2))
wwwMinimalCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 65, 2, 1, 1)).setObjects(*(("WWW-MIB", "wwwServiceGroup"), ("WWW-MIB", "wwwSummaryGroup"),))
if mibBuilder.loadTexts: wwwMinimalCompliance.setDescription('The compliance statement for SNMP agents which implement\n            the minimal subset of the WWW-MIB. Implementors might\n            choose this subset for high-performance server where\n            full compliance might be to expensive.')
wwwFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 65, 2, 1, 2)).setObjects(*(("WWW-MIB", "wwwServiceGroup"), ("WWW-MIB", "wwwSummaryGroup"), ("WWW-MIB", "wwwRequestInGroup"), ("WWW-MIB", "wwwResponseOutGroup"), ("WWW-MIB", "wwwRequestOutGroup"), ("WWW-MIB", "wwwResponseInGroup"), ("WWW-MIB", "wwwDocumentGroup"),))
if mibBuilder.loadTexts: wwwFullCompliance.setDescription('The compliance statement for SNMP agents which implement\n            the full WWW-MIB.')
wwwServiceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 65, 2, 2, 1)).setObjects(*(("WWW-MIB", "wwwServiceDescription"), ("WWW-MIB", "wwwServiceContact"), ("WWW-MIB", "wwwServiceProtocol"), ("WWW-MIB", "wwwServiceName"), ("WWW-MIB", "wwwServiceType"), ("WWW-MIB", "wwwServiceStartTime"), ("WWW-MIB", "wwwServiceOperStatus"), ("WWW-MIB", "wwwServiceLastChange"),))
if mibBuilder.loadTexts: wwwServiceGroup.setDescription('A collection of objects providing information about\n            the WWW services known by the SNMP agent.')
wwwSummaryGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 65, 2, 2, 2)).setObjects(*(("WWW-MIB", "wwwSummaryInRequests"), ("WWW-MIB", "wwwSummaryOutRequests"), ("WWW-MIB", "wwwSummaryInResponses"), ("WWW-MIB", "wwwSummaryOutResponses"), ("WWW-MIB", "wwwSummaryInBytes"), ("WWW-MIB", "wwwSummaryInLowBytes"), ("WWW-MIB", "wwwSummaryOutBytes"), ("WWW-MIB", "wwwSummaryOutLowBytes"),))
if mibBuilder.loadTexts: wwwSummaryGroup.setDescription('A collection of objects providing summary statistics\n            about requests and responses generated and received\n            by a WWW service.')
wwwRequestInGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 65, 2, 2, 3)).setObjects(*(("WWW-MIB", "wwwRequestInRequests"), ("WWW-MIB", "wwwRequestInBytes"), ("WWW-MIB", "wwwRequestInLastTime"),))
if mibBuilder.loadTexts: wwwRequestInGroup.setDescription('A collection of objects providing detailed statistics\n            about requests received by a WWW service.')
wwwRequestOutGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 65, 2, 2, 4)).setObjects(*(("WWW-MIB", "wwwRequestOutRequests"), ("WWW-MIB", "wwwRequestOutBytes"), ("WWW-MIB", "wwwRequestOutLastTime"),))
if mibBuilder.loadTexts: wwwRequestOutGroup.setDescription('A collection of objects providing detailed statistics\n            about requests generated by a WWW service.')
wwwResponseInGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 65, 2, 2, 5)).setObjects(*(("WWW-MIB", "wwwResponseInResponses"), ("WWW-MIB", "wwwResponseInBytes"), ("WWW-MIB", "wwwResponseInLastTime"),))
if mibBuilder.loadTexts: wwwResponseInGroup.setDescription('A collection of objects providing detailed statistics\n            about responses received by a WWW service.')
wwwResponseOutGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 65, 2, 2, 6)).setObjects(*(("WWW-MIB", "wwwResponseOutResponses"), ("WWW-MIB", "wwwResponseOutBytes"), ("WWW-MIB", "wwwResponseOutLastTime"),))
if mibBuilder.loadTexts: wwwResponseOutGroup.setDescription('A collection of objects providing detailed statistics\n            about responses generated by a WWW service.')
wwwDocumentGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 65, 2, 2, 7)).setObjects(*(("WWW-MIB", "wwwDocCtrlLastNSize"), ("WWW-MIB", "wwwDocCtrlLastNLock"), ("WWW-MIB", "wwwDocCtrlBuckets"), ("WWW-MIB", "wwwDocCtrlBucketTimeInterval"), ("WWW-MIB", "wwwDocCtrlTopNSize"), ("WWW-MIB", "wwwDocLastNName"), ("WWW-MIB", "wwwDocLastNTimeStamp"), ("WWW-MIB", "wwwDocLastNRequestType"), ("WWW-MIB", "wwwDocLastNResponseType"), ("WWW-MIB", "wwwDocLastNStatusMsg"), ("WWW-MIB", "wwwDocLastNBytes"), ("WWW-MIB", "wwwDocBucketTimeStamp"), ("WWW-MIB", "wwwDocBucketAccesses"), ("WWW-MIB", "wwwDocBucketDocuments"), ("WWW-MIB", "wwwDocBucketBytes"), ("WWW-MIB", "wwwDocAccessTopNName"), ("WWW-MIB", "wwwDocAccessTopNAccesses"), ("WWW-MIB", "wwwDocAccessTopNBytes"), ("WWW-MIB", "wwwDocAccessTopNLastResponseType"), ("WWW-MIB", "wwwDocBytesTopNName"), ("WWW-MIB", "wwwDocBytesTopNAccesses"), ("WWW-MIB", "wwwDocBytesTopNBytes"), ("WWW-MIB", "wwwDocBytesTopNLastResponseType"),))
if mibBuilder.loadTexts: wwwDocumentGroup.setDescription('A collection of objects providing information about\n            accesses to documents.')
mibBuilder.exportSymbols("WWW-MIB", wwwDocBytesTopNName=wwwDocBytesTopNName, wwwResponseOutEntry=wwwResponseOutEntry, wwwDocLastNTimeStamp=wwwDocLastNTimeStamp, wwwDocLastNEntry=wwwDocLastNEntry, wwwDocLastNName=wwwDocLastNName, wwwMIBCompliances=wwwMIBCompliances, wwwDocCtrlLastNLock=wwwDocCtrlLastNLock, wwwSummaryOutResponses=wwwSummaryOutResponses, wwwDocAccessTopNAccesses=wwwDocAccessTopNAccesses, wwwRequestInBytes=wwwRequestInBytes, wwwRequestOutLastTime=wwwRequestOutLastTime, wwwService=wwwService, wwwResponseOutBytes=wwwResponseOutBytes, wwwDocLastNIndex=wwwDocLastNIndex, wwwMIB=wwwMIB, wwwMinimalCompliance=wwwMinimalCompliance, wwwResponseInIndex=wwwResponseInIndex, wwwRequestInEntry=wwwRequestInEntry, wwwMIBConformance=wwwMIBConformance, wwwRequestInTable=wwwRequestInTable, wwwServiceName=wwwServiceName, wwwSummaryInBytes=wwwSummaryInBytes, wwwDocBucketAccesses=wwwDocBucketAccesses, wwwDocAccessTopNIndex=wwwDocAccessTopNIndex, wwwDocLastNRequestType=wwwDocLastNRequestType, wwwServiceProtocol=wwwServiceProtocol, wwwDocumentStatistics=wwwDocumentStatistics, wwwDocBucketBytes=wwwDocBucketBytes, wwwRequestInGroup=wwwRequestInGroup, wwwSummaryInResponses=wwwSummaryInResponses, wwwResponseOutGroup=wwwResponseOutGroup, WwwResponseType=WwwResponseType, wwwSummaryOutBytes=wwwSummaryOutBytes, wwwDocCtrlBuckets=wwwDocCtrlBuckets, wwwRequestOutRequests=wwwRequestOutRequests, wwwDocCtrlTable=wwwDocCtrlTable, wwwRequestOutGroup=wwwRequestOutGroup, wwwRequestInRequests=wwwRequestInRequests, wwwRequestInIndex=wwwRequestInIndex, wwwFullCompliance=wwwFullCompliance, wwwRequestInLastTime=wwwRequestInLastTime, wwwServiceContact=wwwServiceContact, wwwServiceGroup=wwwServiceGroup, wwwResponseInTable=wwwResponseInTable, wwwSummaryOutLowBytes=wwwSummaryOutLowBytes, wwwDocAccessTopNLastResponseType=wwwDocAccessTopNLastResponseType, wwwRequestOutEntry=wwwRequestOutEntry, wwwSummaryEntry=wwwSummaryEntry, wwwDocLastNTable=wwwDocLastNTable, wwwRequestOutIndex=wwwRequestOutIndex, wwwDocCtrlEntry=wwwDocCtrlEntry, wwwDocAccessTopNBytes=wwwDocAccessTopNBytes, wwwDocLastNStatusMsg=wwwDocLastNStatusMsg, wwwDocBucketDocuments=wwwDocBucketDocuments, wwwResponseOutTable=wwwResponseOutTable, wwwDocBytesTopNIndex=wwwDocBytesTopNIndex, wwwResponseInLastTime=wwwResponseInLastTime, WwwOperStatus=WwwOperStatus, wwwServiceType=wwwServiceType, wwwDocBytesTopNAccesses=wwwDocBytesTopNAccesses, wwwSummaryTable=wwwSummaryTable, wwwDocBucketTable=wwwDocBucketTable, wwwMIBObjects=wwwMIBObjects, wwwDocBucketIndex=wwwDocBucketIndex, wwwSummaryOutRequests=wwwSummaryOutRequests, wwwDocLastNResponseType=wwwDocLastNResponseType, wwwResponseInBytes=wwwResponseInBytes, wwwServiceIndex=wwwServiceIndex, wwwServiceEntry=wwwServiceEntry, wwwMIBGroups=wwwMIBGroups, wwwDocAccessTopNName=wwwDocAccessTopNName, wwwSummaryGroup=wwwSummaryGroup, wwwProtocolStatistics=wwwProtocolStatistics, wwwDocCtrlBucketTimeInterval=wwwDocCtrlBucketTimeInterval, wwwSummaryInLowBytes=wwwSummaryInLowBytes, wwwDocAccessTopNEntry=wwwDocAccessTopNEntry, wwwServiceTable=wwwServiceTable, PYSNMP_MODULE_ID=wwwMIB, wwwRequestOutBytes=wwwRequestOutBytes, wwwDocBytesTopNEntry=wwwDocBytesTopNEntry, wwwDocLastNBytes=wwwDocLastNBytes, wwwServiceDescription=wwwServiceDescription, WwwRequestType=WwwRequestType, wwwDocCtrlLastNSize=wwwDocCtrlLastNSize, wwwSummaryInRequests=wwwSummaryInRequests, wwwServiceLastChange=wwwServiceLastChange, wwwDocCtrlTopNSize=wwwDocCtrlTopNSize, wwwResponseOutResponses=wwwResponseOutResponses, wwwDocBucketEntry=wwwDocBucketEntry, wwwDocBytesTopNBytes=wwwDocBytesTopNBytes, wwwServiceStartTime=wwwServiceStartTime, wwwDocAccessTopNTable=wwwDocAccessTopNTable, wwwResponseInGroup=wwwResponseInGroup, wwwDocBytesTopNTable=wwwDocBytesTopNTable, wwwResponseInResponses=wwwResponseInResponses, wwwServiceOperStatus=wwwServiceOperStatus, wwwDocBucketTimeStamp=wwwDocBucketTimeStamp, wwwDocBytesTopNLastResponseType=wwwDocBytesTopNLastResponseType, wwwRequestOutTable=wwwRequestOutTable, WwwDocName=WwwDocName, wwwResponseOutIndex=wwwResponseOutIndex, wwwResponseOutLastTime=wwwResponseOutLastTime, wwwResponseInEntry=wwwResponseInEntry, wwwDocumentGroup=wwwDocumentGroup)



#
# PySNMP MIB module HPR-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/HPR-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:15:28 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( SnaControlPointName, ) = mibBuilder.importSymbols("APPN-MIB", "SnaControlPointName")
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ConstraintsIntersection, ValueSizeConstraint, SingleValueConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ConstraintsIntersection", "ValueSizeConstraint", "SingleValueConstraint", "ValueRangeConstraint")
( snanauMIB, ) = mibBuilder.importSymbols("SNA-NAU-MIB", "snanauMIB")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( Counter64, TimeTicks, NotificationType, Bits, Counter32, ObjectIdentity, Gauge32, Integer32, MibIdentifier, ModuleIdentity, IpAddress, iso, MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter64", "TimeTicks", "NotificationType", "Bits", "Counter32", "ObjectIdentity", "Gauge32", "Integer32", "MibIdentifier", "ModuleIdentity", "IpAddress", "iso", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32")
( TextualConvention, DateAndTime, TimeStamp, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DateAndTime", "TimeStamp", "DisplayString")
hprMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 34, 6))
if mibBuilder.loadTexts: hprMIB.setLastUpdated('970514000000Z')
if mibBuilder.loadTexts: hprMIB.setOrganization('AIW APPN / HPR MIB SIG')
if mibBuilder.loadTexts: hprMIB.setContactInfo('\n\n                        Bob Clouston\n                        Cisco Systems\n                        7025 Kit Creek Road\n                        P.O. Box 14987\n                        Research Triangle Park, NC 27709, USA\n                        Tel:    1 919 472 2333\n                        E-mail: clouston@cisco.com\n\n                        Bob Moore\n                        IBM Corporation\n                        800 Park Offices Drive\n                        RHJA/664\n                        P.O. Box 12195\n                        Research Triangle Park, NC 27709, USA\n                        Tel:    1 919 254 4436\n                        E-mail: remoore@ralvm6.vnet.ibm.com\n                ')
if mibBuilder.loadTexts: hprMIB.setDescription('This is the MIB module for objects used to\n                 manage network devices with HPR capabilities.')
class HprNceTypes(Bits, TextualConvention):
    namedValues = NamedValues(("controlPoint", 0), ("logicalUnit", 1), ("boundaryFunction", 2), ("routeSetup", 3),)

class HprRtpCounter(Counter32, TextualConvention):
    pass

hprObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 34, 6, 1))
hprGlobal = MibIdentifier((1, 3, 6, 1, 2, 1, 34, 6, 1, 1))
hprNodeCpName = MibScalar((1, 3, 6, 1, 2, 1, 34, 6, 1, 1, 1), SnaControlPointName()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprNodeCpName.setDescription('Administratively assigned network name for the APPN node\n          where this HPR implementation resides.  If this object has\n          the same value as the appnNodeCpName object in the APPN MIB,\n          then the two objects are referring to the same APPN node.')
hprOperatorPathSwitchSupport = MibScalar((1, 3, 6, 1, 2, 1, 34, 6, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("notSupported", 1), ("switchTriggerSupported", 2), ("switchToPathSupported", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprOperatorPathSwitchSupport.setDescription("This object indicates an implementation's level of support\n          for an operator-requested path switch.\n\n            notSupported(1)           - the agent does not support\n                                        operator-requested path switches\n            switchTriggerSupported(2) - the agent supports a 'switch\n                                        path now' command from an\n                                        operator, but not a command to\n                                        switch to a specified path\n            switchToPathSupported(3)  - the agent supports both a\n                                        'switch path now' command and a\n                                        command to switch to a specified\n                                        path.  Note that the latter\n                                        command is not available via\n                                        this MIB; a system that supports\n                                        it must do so via other means,\n                                        such as a local operator\n                                        interface.")
hprAnrRouting = MibIdentifier((1, 3, 6, 1, 2, 1, 34, 6, 1, 2))
hprAnrsAssigned = MibScalar((1, 3, 6, 1, 2, 1, 34, 6, 1, 2, 1), Counter32()).setUnits('ANR labels').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprAnrsAssigned.setDescription('The count of ANR labels assigned by this node since it was\n          last re-initialized.  A Management Station can detect\n          discontinuities in this counter by monitoring the\n          appnNodeCounterDisconTime object in the APPN MIB.')
hprAnrCounterState = MibScalar((1, 3, 6, 1, 2, 1, 34, 6, 1, 2, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("notActive", 1), ("active", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: hprAnrCounterState.setDescription('This object is used for a network management station to turn\n          on/off the counting of ANR packets in the hprAnrRoutingTable.\n          The initial value of this object is an implementation choice.\n\n                 notActive(1) - the counter hprAnrPacketsReceived\n                                returns no meaningful value\n                 active(2)    - the counter hprAnrPacketsReceived is\n                                being incremented and is returning\n                                meaningful values')
hprAnrCounterStateTime = MibScalar((1, 3, 6, 1, 2, 1, 34, 6, 1, 2, 3), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprAnrCounterStateTime.setDescription('The time when the hprAnrCounterState object last changed its\n          value.  The initial value returned by this object is the time\n          at which the APPN node instrumented with this MIB was last\n          brought up.')
hprAnrRoutingTable = MibTable((1, 3, 6, 1, 2, 1, 34, 6, 1, 2, 4), )
if mibBuilder.loadTexts: hprAnrRoutingTable.setDescription('The ANR Routing table provides a means of correlating an\n          incoming ANR label (i.e., one assigned by this node) with the\n          TG over which a packet containing the label will be forwarded.\n          When the ANR label identifies a local NCE, the hprAnrOutTgDest\n          and hprAnrOutTgNum objects have no meaning.  The table also\n          contains an object to count the number of packets received\n          with a given ANR label.')
hprAnrRoutingEntry = MibTableRow((1, 3, 6, 1, 2, 1, 34, 6, 1, 2, 4, 1), ).setIndexNames((0, "HPR-MIB", "hprAnrLabel"))
if mibBuilder.loadTexts: hprAnrRoutingEntry.setDescription('The ANR label is used to index this table.')
hprAnrLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 2, 4, 1, 1), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,8)))
if mibBuilder.loadTexts: hprAnrLabel.setDescription('The first ANR label in an incoming packet.')
hprAnrType = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 2, 4, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("nce", 1), ("tg", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprAnrType.setDescription('An object indicating whether an ANR label assigned by this\n          node identifies a local NCE or a TG on which outgoing packets\n          are forwarded.\n\n              nce(1)  - the ANR label identifies a local NCE.  In this\n                        case the hprAnrOutTgDest and hprAnrOutTgNum\n                        objects have no meaning.\n              tg(2)   - the ANR label identifies a TG.')
hprAnrOutTgDest = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 2, 4, 1, 3), DisplayString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(3,17),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprAnrOutTgDest.setDescription('Destination node for the TG over which packets with this ANR\n          label are forwarded.  This is the fully qualified name of an\n          APPN network node or end node, formatted according to the\n          SnaControlPointName textual convention.  If the ANR label\n          identifies a local NCE, then this object returns a zero-length\n          string.\n\n          This object corresponds to the appnLocalTgDest object in the\n          APPN MIB.')
hprAnrOutTgNum = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 2, 4, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprAnrOutTgNum.setDescription('Number of the TG over which packets with this ANR label are\n          forwarded.  If the ANR label identifies a local NCE, then this\n          object returns the value 0, since 0 is not a valid TG number\n          for a TG that supports HPR.\n\n          This object corresponds to the appnLocalTgNum object in the\n          APPN MIB.')
hprAnrPacketsReceived = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 2, 4, 1, 5), Counter32()).setUnits('ANR packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprAnrPacketsReceived.setDescription('The count of packets received with this ANR label as their\n          first label.\n\n          A Management Station can detect discontinuities in this\n          counter by monitoring the hprAnrCounterDisconTime object in\n          the same row.')
hprAnrCounterDisconTime = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 2, 4, 1, 6), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprAnrCounterDisconTime.setDescription('The value of the sysUpTime object when the\n          hprAnrPacketsReceived counter for this ANR label last\n          experienced a discontinuity.  This will be the more recent of\n          two times:  the time at which the ANR label was associated with\n          either an outgoing TG or a local NCE, or the time at which the\n          ANR counters were last turned on or off.')
hprTransportUser = MibIdentifier((1, 3, 6, 1, 2, 1, 34, 6, 1, 3))
hprNceTable = MibTable((1, 3, 6, 1, 2, 1, 34, 6, 1, 3, 1), )
if mibBuilder.loadTexts: hprNceTable.setDescription('The Network Connection Endpoint (NCE) table.')
hprNceEntry = MibTableRow((1, 3, 6, 1, 2, 1, 34, 6, 1, 3, 1, 1), ).setIndexNames((0, "HPR-MIB", "hprNceId"))
if mibBuilder.loadTexts: hprNceEntry.setDescription('The NCE ID is used to index this table.')
hprNceId = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 3, 1, 1, 1), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,8)))
if mibBuilder.loadTexts: hprNceId.setDescription('The Network Connection Endpoint (NCE) ID.  NCEs identify\n          Control Points (Cp), Logical Units (Lu), HPR Boundary\n          Functions (Bf) and Route Setup (Rs) Functions.  A value for\n          this object can be retrieved from any of the following\n          objects in the APPN MIB:\n\n               - appnLsCpCpNceId\n               - appnLsRouteNceId\n               - appnLsBfNceId\n               - appnIsInRtpNceId\n               - appnIsRtpNceId\n\n          In each case this value identifies a row in this table\n          containing information related to that in the APPN MIB.')
hprNceType = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 3, 1, 1, 2), HprNceTypes()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprNceType.setDescription('A bit string identifying the function types provided by this\n          Network Connection Endpoint (NCE).')
hprNceDefault = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 3, 1, 1, 3), HprNceTypes()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprNceDefault.setDescription('A bit string identifying the function types for which this\n          Network Connection Endpoint (NCE) is the default NCE.  While\n          default NCEs are not explicitly defined in the architecture,\n          some implementations provide them; for such implementations,\n          it is useful to make this information available to a\n          Management Station.')
hprNceInstanceId = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 3, 1, 1, 4), OctetString().subtype(subtypeSpec=ValueSizeConstraint(4,4)).setFixedLength(4)).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprNceInstanceId.setDescription("The NCE instance identifier (NCEII) identifying the current\n          instance of this NCE.  An NCEII is used to denote different\n          instances (IPLs) of an NCE component.  Each time an NCE is\n          activated (IPL'd), it acquires a different, unique NCEII.")
hprRtp = MibIdentifier((1, 3, 6, 1, 2, 1, 34, 6, 1, 4))
hprRtpGlobe = MibIdentifier((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 1))
hprRtpGlobeConnSetups = MibScalar((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 1, 1), Counter32()).setUnits('RTP connection setups').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpGlobeConnSetups.setDescription('The count of RTP connection setups in which this node has\n          participated, as either sender or receiver, since it was last\n          re-initialized.  Retries of a setup attempt do not cause the\n          counter to be incremented.\n\n          A Management Station can detect discontinuities in this\n          counter by monitoring the appnNodeCounterDisconTime object\n          in the APPN MIB.')
hprRtpGlobeCtrState = MibScalar((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("notActive", 1), ("active", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: hprRtpGlobeCtrState.setDescription('This object allows a network management station to turn the\n          counters in the hprRtpTable on and off.  The initial value of\n          this object is an implementation choice.\n\n                 notActive(1) - the counters in the hprRtpTable are\n                                returning no meaningful values\n                 active(2)    - the counters in the hprRtpTable are\n                                being incremented and are returning\n                                meaningful values')
hprRtpGlobeCtrStateTime = MibScalar((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 1, 3), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpGlobeCtrStateTime.setDescription('The time when the value of the hprRtpGlobeCtrState object\n          last changed.  The initial value returned by this object is\n          the time at which the APPN node instrumented with this MIB\n          was last brought up.')
hprRtpTable = MibTable((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2), )
if mibBuilder.loadTexts: hprRtpTable.setDescription('The RTP Connection table')
hprRtpEntry = MibTableRow((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1), ).setIndexNames((0, "HPR-MIB", "hprRtpLocNceId"), (0, "HPR-MIB", "hprRtpLocTcid"))
if mibBuilder.loadTexts: hprRtpEntry.setDescription('The local NCE ID and local TCID are used to index this\n          table.')
hprRtpLocNceId = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 1), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,8)))
if mibBuilder.loadTexts: hprRtpLocNceId.setDescription('The local Network Connection Endpoint (NCE) ID of this RTP\n          connection.  NCEs identify CPs, LUs, Boundary Functions (BFs),\n          and Route Setup (RS) components.  A value for this object can\n          be retrieved from any of the following objects in the APPN\n          MIB:\n\n               - appnLsCpCpNceId\n               - appnLsRouteNceId\n               - appnLsBfNceId\n               - appnIsInRtpNceId\n               - appnIsRtpNceId\n\n          In each case this value identifies a row in this table\n          containing information related to that in the APPN MIB.')
hprRtpLocTcid = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 2), OctetString().subtype(subtypeSpec=ValueSizeConstraint(8,8)).setFixedLength(8))
if mibBuilder.loadTexts: hprRtpLocTcid.setDescription('The local TCID of this RTP connection.  A value for this\n          object can be retrieved from either the appnIsInRtpTcid object\n          or the appnIsRtpTcid object the APPN MIB; in each case this\n          value identifies a row in this table containing information\n          related to that in the APPN MIB.')
hprRtpRemCpName = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 3), SnaControlPointName()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpRemCpName.setDescription('Administratively assigned network name for the remote node of\n          this RTP connection.')
hprRtpRemNceId = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 4), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,8))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpRemNceId.setDescription('The remote Network Connection Endpoint (NCE) of this RTP\n          connection.  NCEs identify CPs, LUs, Boundary Functions (BFs),\n          and Route Setup (RS) components.')
hprRtpRemTcid = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 5), OctetString().subtype(subtypeSpec=ValueSizeConstraint(8,8)).setFixedLength(8)).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpRemTcid.setDescription('The remote TCID of this RTP connection.')
hprRtpPathSwitchTrigger = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("ready", 1), ("switchPathNow", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: hprRtpPathSwitchTrigger.setDescription('Object by which a Management Station can trigger an operator-\n          requested path switch, by setting the value to\n          switchPathNow(2).  Setting this object to switchPathNow(2)\n          triggers a path switch even if its previous value was already\n          switchPathNow(2).\n          The value ready(1) is returned on GET operations until a SET\n          has been processed; after that the value received on the most\n          recent SET is returned.\n\n          This MIB module provides no support for an operator-requested\n          switch to a specified path.')
hprRtpRscv = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 7), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpRscv.setDescription('The forward Route Selection Control Vector for this RTP\n          connection.  The format of this vector is described in SNA\n          Formats.\n\n          The value returned in this object during a path switch is\n          implementation-dependent:  it may be the old path, the new\n          path, a zero-length string, or some other valid RSCV string.')
hprRtpTopic = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 8), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(8,8)).setFixedLength(8)).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpTopic.setDescription('The topic for this RTP connection.  This is used to indicate\n          the Class of Service.')
hprRtpState = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 9), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 99,))).clone(namedValues=NamedValues(("rtpListening", 1), ("rtpCalling", 2), ("rtpConnected", 3), ("rtpPathSwitching", 4), ("rtpDisconnecting", 5), ("other", 99),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpState.setDescription("The state of the RTP connection, from the perspective of the\n          local RTP protocol machine:\n              rtpListening      - connection open; waiting for other end\n                                  to call in\n              rtpCalling        - connection opened, attempting to call\n                                  out, have not yet received any data\n                                  from other end\n              rtpConnected      - connection is active; responded to a\n                                  call-in or received other end's TCID\n                                  from a call-out attempt\n              rtpPathSwitching  - the path switch timer is running;\n                                  attempting to find a new path for this\n                                  connection.\n              rtpDisconnecting  - no sessions are using this connection;\n                                  in process of bringing it down\n              other             - the connection is not in any of the\n                                  states listed above.")
hprRtpUpTime = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 10), TimeTicks()).setUnits('1/100ths of a second').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpUpTime.setDescription('The length of time the RTP connection has been up, measured\n          in 1/100ths of a second.')
hprRtpLivenessTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 11), Unsigned32()).setUnits('1/100ths of a second').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpLivenessTimer.setDescription('The value of the liveness (ALIVE) timer of this RTP\n          connection, in units of 1/100th of a second.  When this timer\n          expires and no packet has arrived from the partner since it\n          was last set, packets with Status Request indicators will be\n          sent to see if the RTP connection is still alive.')
hprRtpShortReqTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 12), Unsigned32()).setUnits('1/100ths of a second').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpShortReqTimer.setDescription('The value of the RTP SHORT-REQ timer, in units of 1/100 of a\n          second.  This timer represents the maximum time that a sender\n          waits for a reply from a receiver.')
hprRtpPathSwTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 13), Unsigned32()).setUnits('1/100ths of a second').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpPathSwTimer.setDescription('The length of time that RTP should attempt a path switch\n          for a connection, in units of 1/100th of a second.')
hprRtpLivenessTimeouts = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 14), HprRtpCounter()).setUnits('liveness timeouts').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpLivenessTimeouts.setDescription('The count of liveness timeouts for this RTP connection.')
hprRtpShortReqTimeouts = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 15), HprRtpCounter()).setUnits('short request timeouts').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpShortReqTimeouts.setDescription('The count of short request timeouts for this RTP connection.')
hprRtpMaxSendRate = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 16), Gauge32()).setUnits('bytes per second').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpMaxSendRate.setDescription("The high-water mark for this RTP connection's send rate, in\n          units of bytes per second.  This is the high-water mark for\n          the entire life of the connection, not just the high-water\n          mark for the connection's current path.\n          For more details on this and other parameters related to HPR,\n          see the High Performance Routing Architecture Reference.")
hprRtpMinSendRate = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 17), Gauge32()).setUnits('bytes per second').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpMinSendRate.setDescription("The low-water mark for this RTP connection's send rate, in\n          units of bytes per second.  This is the low-water mark for the\n          entire life of the connection, not just the low-water mark for\n          the connection's current path.\n\n          For more details on this and other parameters related to HPR,\n          see the High Performance Routing Architecture Reference.")
hprRtpCurSendRate = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 18), Gauge32()).setUnits('bytes per second').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpCurSendRate.setDescription('The current send rate for this RTP connection, in units of\n          bytes per second.\n\n          For more details on this and other parameters related to HPR,\n          see the High Performance Routing Architecture Reference.')
hprRtpSmRdTripDelay = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 19), Gauge32()).setUnits('1/1000ths of a second').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpSmRdTripDelay.setDescription('The smoothed round trip delay for this RTP connection, in\n          units of 1/1000th of a second (ms).\n\n          For more details on this and other parameters related to HPR,\n          see the High Performance Routing Architecture Reference.')
hprRtpSendPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 20), HprRtpCounter()).setUnits('RTP packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpSendPackets.setDescription('The count of packets successfully sent on this RTP\n          connection.')
hprRtpRecvPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 21), HprRtpCounter()).setUnits('RTP packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpRecvPackets.setDescription('The count of packets received on this RTP connection.  The\n          counter is incremented only once if duplicate copies of a\n          packet are received.')
hprRtpSendBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 22), HprRtpCounter()).setUnits('bytes').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpSendBytes.setDescription('The count of bytes sent on this RTP connection.  Both RTP\n          Transport Header (THDR) bytes and data bytes are included in\n          this count.')
hprRtpRecvBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 23), HprRtpCounter()).setUnits('bytes').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpRecvBytes.setDescription('The count of bytes received on this RTP connection.  Both RTP\n          Transport Header (THDR) bytes and data bytes are included in\n          this count.')
hprRtpRetrPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 24), HprRtpCounter()).setUnits('RTP packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpRetrPackets.setDescription('The count of packets retransmitted on this RTP connection.')
hprRtpPacketsDiscarded = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 25), HprRtpCounter()).setUnits('RTP packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpPacketsDiscarded.setDescription('The count of packets received on this RTP connection and then\n          discarded.  A packet may be discarded because it is determined\n          to be a duplicate, or for other reasons.')
hprRtpDetectGaps = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 26), HprRtpCounter()).setUnits('gaps').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpDetectGaps.setDescription('The count of gaps detected on this RTP connection.')
hprRtpRateReqSends = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 27), HprRtpCounter()).setUnits('rate requests').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpRateReqSends.setDescription('The count of Rate Requests sent on this RTP connection.')
hprRtpOkErrPathSws = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 28), HprRtpCounter()).setUnits('path switch attempts').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpOkErrPathSws.setDescription('The count of successful path switch attempts for this RTP\n          connection due to errors.')
hprRtpBadErrPathSws = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 29), HprRtpCounter()).setUnits('path switch attempts').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpBadErrPathSws.setDescription('The count of unsuccessful path switches for this RTP\n          connection due to errors.')
hprRtpOkOpPathSws = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 30), HprRtpCounter()).setUnits('path switches').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpOkOpPathSws.setDescription('The count of successful path switches for this RTP connection\n          due to operator requests.')
hprRtpBadOpPathSws = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 31), HprRtpCounter()).setUnits('path switches').setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpBadOpPathSws.setDescription('The count of unsuccessful path switches for this RTP\n          connection due to operator requests.  This counter is not\n          incremented by an implementation that does not support\n          operator-requested path switches, even if a Management Station\n          requests such a path switch by setting the\n          hprRtpPathSwitchTrigger object.')
hprRtpCounterDisconTime = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 2, 1, 32), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpCounterDisconTime.setDescription('The value of the sysUpTime object when the counters for this\n          RTP connection last experienced a discontinuity.  This will be\n          the more recent of two times:  the time at which the\n          connection was established or the time at which the HPR\n          counters were last turned on or off.')
hprRtpStatusTable = MibTable((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 3), )
if mibBuilder.loadTexts: hprRtpStatusTable.setDescription('RTP Connection Status Table:  This table contains historical\n          information on RTP connections.  An entry is created in this\n          table when a path switch is completed, either successfully or\n          unsuccessfully.')
hprRtpStatusEntry = MibTableRow((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 3, 1), ).setIndexNames((0, "HPR-MIB", "hprRtpStatusLocNceId"), (0, "HPR-MIB", "hprRtpStatusLocTcid"), (0, "HPR-MIB", "hprRtpStatusIndex"))
if mibBuilder.loadTexts: hprRtpStatusEntry.setDescription('This table is indexed by local NCE ID, local TCID, and an\n          integer hprRtpStatusIndex.  Thus the primary grouping of table\n          rows is by RTP connection, with the multiple entries for a\n          given RTP connection ordered by time.')
hprRtpStatusLocNceId = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 3, 1, 1), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,8)))
if mibBuilder.loadTexts: hprRtpStatusLocNceId.setDescription('The local Network Connection Endpoint (NCE) of this RTP\n          connection.  NCEs identify CPs, LUs, Boundary Functions (BFs),\n          and Route Setup (RS) components.')
hprRtpStatusLocTcid = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 3, 1, 2), OctetString().subtype(subtypeSpec=ValueSizeConstraint(8,8)).setFixedLength(8))
if mibBuilder.loadTexts: hprRtpStatusLocTcid.setDescription('The local TCID of this RTP connection.')
hprRtpStatusIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 3, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: hprRtpStatusIndex.setDescription('Table index.  This value begins at one and is incremented\n          when a new entry is added to the table.  It is an\n          implementation choice whether to run a single counter for\n          all entries in the table, or to run a separate counter for\n          the entries for each RTP connection.  In the unlikely event\n          of a wrap, it is assumed that Management Stations will have\n          the ability to order table entries correctly.')
hprRtpStatusStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 3, 1, 4), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpStatusStartTime.setDescription('The time when the path switch began.')
hprRtpStatusEndTime = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 3, 1, 5), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpStatusEndTime.setDescription('The time when the path switch was ended, either successfully\n          or unsuccessfully.')
hprRtpStatusRemCpName = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 3, 1, 6), SnaControlPointName()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpStatusRemCpName.setDescription('Administratively assigned network name for the remote node of\n          this RTP connection.')
hprRtpStatusRemNceId = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 3, 1, 7), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,8))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpStatusRemNceId.setDescription('The remote Network Connection Endpoint (NCE) of this RTP\n          connection.  NCEs identify CPs, LUs, Boundary Functions (BFs),\n          and Route Setup (RS) components.')
hprRtpStatusRemTcid = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 3, 1, 8), OctetString().subtype(subtypeSpec=ValueSizeConstraint(8,8)).setFixedLength(8)).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpStatusRemTcid.setDescription('The remote TCID of this RTP connection.')
hprRtpStatusNewRscv = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 3, 1, 9), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpStatusNewRscv.setDescription('The new Route Selection Control Vector for this RTP\n          connection.  A zero-length string indicates that no value is\n          available, perhaps because the implementation does not save\n          RSCVs.')
hprRtpStatusOldRscv = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 3, 1, 10), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpStatusOldRscv.setDescription('The old Route Selection Control Vector for this RTP\n          connection.  A zero-length string indicates that no value is\n          available, perhaps because the implementation does not save\n          RSCVs.')
hprRtpStatusCause = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 3, 1, 11), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("other", 1), ("rtpConnFail", 2), ("locLinkFail", 3), ("remLinkFail", 4), ("operRequest", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpStatusCause.setDescription('The reason for the path switch:\n\n               other(1)       - Reason other than those listed below,\n               rtpConnFail(2) - RTP connection failure detected,\n               locLinkFail(3) - Local link failure,\n               remLinkFail(4) - Remote link failure (learned from TDUs),\n               operRequest(5) - Operator requested path switch. ')
hprRtpStatusLastAttemptResult = MibTableColumn((1, 3, 6, 1, 2, 1, 34, 6, 1, 4, 3, 1, 12), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8,))).clone(namedValues=NamedValues(("successful", 1), ("initiatorMoving", 2), ("directorySearchFailed", 3), ("rscvCalculationFailed", 4), ("negativeRouteSetupReply", 5), ("backoutRouteSetupReply", 6), ("timeoutDuringFirstAttempt", 7), ("otherUnsuccessful", 8),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hprRtpStatusLastAttemptResult.setDescription("The result of the last completed path switch attempt.  If the\n          path switch is aborted in the middle of a path switch attempt\n          because the path switch timer expires, the result of the\n          previous path switch attempt is reported.\n\n          The values are defined as follows:\n\n             successful(1)                - The final path switch\n                                            attempt was successful.\n             initiatorMoving(2)           - The final path switch\n                                            attempt failed because the\n                                            initiator is mobile, and\n                                            there was no active link\n                                            out of this node.\n             directorySearchFailed(3)     - The final path switch\n                                            attempt failed because a\n                                            directory search for the\n                                            destination node's CP name\n                                            failed.\n             rscvCalculationFailed(4)     - The final path switch\n                                            attempt failed because an\n                                            RSCV to the node containing\n                                            the remote RTP endpoint\n                                            could not be calculated.\n             negativeRouteSetupReply(5)   - The final path switch\n                                            attempt failed because route\n                                            setup failed for the new\n                                            path.\n             backoutRouteSetupReply(6)    - The final path switch\n                                            attempt failed because the\n                                            remote RTP endpoint refused\n                                            to continue the RTP\n                                            connection.\n             timeoutDuringFirstAttempt(7) - The path switch timer\n                                            expired during the first\n                                            path switch attempt.\n             otherUnsuccessful(8)         - The final path switch\n                                            attempt failed for a reason\n                                            other than those listed\n                                            above.")
hprConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 34, 6, 2))
hprCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 34, 6, 2, 1))
hprGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 34, 6, 2, 2))
hprCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 34, 6, 2, 1, 1)).setObjects(*(("HPR-MIB", "hprGlobalConfGroup"), ("HPR-MIB", "hprAnrRoutingConfGroup"), ("HPR-MIB", "hprTransportUserConfGroup"), ("HPR-MIB", "hprRtpConfGroup"),))
if mibBuilder.loadTexts: hprCompliance.setDescription('The compliance statement for the SNMPv2 entities that\n          implement the HPR MIB.')
hprGlobalConfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 34, 6, 2, 2, 1)).setObjects(*(("HPR-MIB", "hprNodeCpName"), ("HPR-MIB", "hprOperatorPathSwitchSupport"),))
if mibBuilder.loadTexts: hprGlobalConfGroup.setDescription('A collection of objects providing the instrumentation of HPR\n          general information and capabilities.')
hprAnrRoutingConfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 34, 6, 2, 2, 2)).setObjects(*(("HPR-MIB", "hprAnrsAssigned"), ("HPR-MIB", "hprAnrCounterState"), ("HPR-MIB", "hprAnrCounterStateTime"), ("HPR-MIB", "hprAnrType"), ("HPR-MIB", "hprAnrOutTgDest"), ("HPR-MIB", "hprAnrOutTgNum"), ("HPR-MIB", "hprAnrPacketsReceived"), ("HPR-MIB", "hprAnrCounterDisconTime"),))
if mibBuilder.loadTexts: hprAnrRoutingConfGroup.setDescription("A collection of objects providing instrumentation for the\n          node's ANR routing.")
hprTransportUserConfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 34, 6, 2, 2, 3)).setObjects(*(("HPR-MIB", "hprNceType"), ("HPR-MIB", "hprNceDefault"), ("HPR-MIB", "hprNceInstanceId"),))
if mibBuilder.loadTexts: hprTransportUserConfGroup.setDescription('A collection of objects providing information on the users of\n          the HPR transport known to the node.')
hprRtpConfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 34, 6, 2, 2, 4)).setObjects(*(("HPR-MIB", "hprRtpGlobeConnSetups"), ("HPR-MIB", "hprRtpGlobeCtrState"), ("HPR-MIB", "hprRtpGlobeCtrStateTime"), ("HPR-MIB", "hprRtpRemCpName"), ("HPR-MIB", "hprRtpRemNceId"), ("HPR-MIB", "hprRtpRemTcid"), ("HPR-MIB", "hprRtpPathSwitchTrigger"), ("HPR-MIB", "hprRtpRscv"), ("HPR-MIB", "hprRtpTopic"), ("HPR-MIB", "hprRtpState"), ("HPR-MIB", "hprRtpUpTime"), ("HPR-MIB", "hprRtpLivenessTimer"), ("HPR-MIB", "hprRtpShortReqTimer"), ("HPR-MIB", "hprRtpPathSwTimer"), ("HPR-MIB", "hprRtpLivenessTimeouts"), ("HPR-MIB", "hprRtpShortReqTimeouts"), ("HPR-MIB", "hprRtpMaxSendRate"), ("HPR-MIB", "hprRtpMinSendRate"), ("HPR-MIB", "hprRtpCurSendRate"), ("HPR-MIB", "hprRtpSmRdTripDelay"), ("HPR-MIB", "hprRtpSendPackets"), ("HPR-MIB", "hprRtpRecvPackets"), ("HPR-MIB", "hprRtpSendBytes"), ("HPR-MIB", "hprRtpRecvBytes"), ("HPR-MIB", "hprRtpRetrPackets"), ("HPR-MIB", "hprRtpPacketsDiscarded"), ("HPR-MIB", "hprRtpDetectGaps"), ("HPR-MIB", "hprRtpRateReqSends"), ("HPR-MIB", "hprRtpOkErrPathSws"), ("HPR-MIB", "hprRtpBadErrPathSws"), ("HPR-MIB", "hprRtpOkOpPathSws"), ("HPR-MIB", "hprRtpBadOpPathSws"), ("HPR-MIB", "hprRtpCounterDisconTime"), ("HPR-MIB", "hprRtpStatusStartTime"), ("HPR-MIB", "hprRtpStatusEndTime"), ("HPR-MIB", "hprRtpStatusRemNceId"), ("HPR-MIB", "hprRtpStatusRemTcid"), ("HPR-MIB", "hprRtpStatusRemCpName"), ("HPR-MIB", "hprRtpStatusNewRscv"), ("HPR-MIB", "hprRtpStatusOldRscv"), ("HPR-MIB", "hprRtpStatusCause"), ("HPR-MIB", "hprRtpStatusLastAttemptResult"),))
if mibBuilder.loadTexts: hprRtpConfGroup.setDescription('A collection of objects providing the instrumentation for RTP\n          connection end points.')
mibBuilder.exportSymbols("HPR-MIB", hprRtpRateReqSends=hprRtpRateReqSends, hprRtpDetectGaps=hprRtpDetectGaps, hprOperatorPathSwitchSupport=hprOperatorPathSwitchSupport, hprRtpLivenessTimeouts=hprRtpLivenessTimeouts, hprRtpMaxSendRate=hprRtpMaxSendRate, hprAnrOutTgNum=hprAnrOutTgNum, hprGlobal=hprGlobal, hprRtpCurSendRate=hprRtpCurSendRate, hprTransportUserConfGroup=hprTransportUserConfGroup, hprRtpRecvBytes=hprRtpRecvBytes, hprAnrRoutingEntry=hprAnrRoutingEntry, hprRtpGlobeConnSetups=hprRtpGlobeConnSetups, hprRtpStatusNewRscv=hprRtpStatusNewRscv, hprNceTable=hprNceTable, hprNceType=hprNceType, hprConformance=hprConformance, hprRtpPacketsDiscarded=hprRtpPacketsDiscarded, hprTransportUser=hprTransportUser, hprGroups=hprGroups, hprAnrPacketsReceived=hprAnrPacketsReceived, hprRtpStatusIndex=hprRtpStatusIndex, hprRtpRscv=hprRtpRscv, hprAnrLabel=hprAnrLabel, hprRtpTopic=hprRtpTopic, HprRtpCounter=HprRtpCounter, hprRtpUpTime=hprRtpUpTime, hprRtpRecvPackets=hprRtpRecvPackets, hprRtpSendPackets=hprRtpSendPackets, PYSNMP_MODULE_ID=hprMIB, hprRtpGlobeCtrState=hprRtpGlobeCtrState, hprRtpStatusLastAttemptResult=hprRtpStatusLastAttemptResult, hprGlobalConfGroup=hprGlobalConfGroup, hprRtp=hprRtp, hprRtpPathSwTimer=hprRtpPathSwTimer, hprRtpCounterDisconTime=hprRtpCounterDisconTime, hprAnrCounterState=hprAnrCounterState, hprAnrOutTgDest=hprAnrOutTgDest, hprRtpState=hprRtpState, hprRtpEntry=hprRtpEntry, hprRtpRemNceId=hprRtpRemNceId, hprAnrRouting=hprAnrRouting, hprRtpOkOpPathSws=hprRtpOkOpPathSws, hprAnrsAssigned=hprAnrsAssigned, hprRtpShortReqTimer=hprRtpShortReqTimer, hprRtpStatusRemTcid=hprRtpStatusRemTcid, hprCompliances=hprCompliances, hprAnrRoutingTable=hprAnrRoutingTable, hprRtpRemTcid=hprRtpRemTcid, hprNodeCpName=hprNodeCpName, hprRtpOkErrPathSws=hprRtpOkErrPathSws, hprRtpStatusOldRscv=hprRtpStatusOldRscv, hprRtpSendBytes=hprRtpSendBytes, hprRtpStatusEndTime=hprRtpStatusEndTime, hprRtpGlobe=hprRtpGlobe, hprRtpBadOpPathSws=hprRtpBadOpPathSws, hprRtpSmRdTripDelay=hprRtpSmRdTripDelay, HprNceTypes=HprNceTypes, hprRtpStatusRemNceId=hprRtpStatusRemNceId, hprAnrType=hprAnrType, hprRtpStatusStartTime=hprRtpStatusStartTime, hprMIB=hprMIB, hprRtpConfGroup=hprRtpConfGroup, hprNceEntry=hprNceEntry, hprNceId=hprNceId, hprRtpStatusEntry=hprRtpStatusEntry, hprRtpGlobeCtrStateTime=hprRtpGlobeCtrStateTime, hprRtpStatusLocTcid=hprRtpStatusLocTcid, hprRtpStatusTable=hprRtpStatusTable, hprAnrCounterStateTime=hprAnrCounterStateTime, hprRtpPathSwitchTrigger=hprRtpPathSwitchTrigger, hprRtpStatusRemCpName=hprRtpStatusRemCpName, hprRtpLocNceId=hprRtpLocNceId, hprRtpRemCpName=hprRtpRemCpName, hprRtpBadErrPathSws=hprRtpBadErrPathSws, hprCompliance=hprCompliance, hprRtpStatusCause=hprRtpStatusCause, hprRtpTable=hprRtpTable, hprAnrRoutingConfGroup=hprAnrRoutingConfGroup, hprObjects=hprObjects, hprRtpRetrPackets=hprRtpRetrPackets, hprRtpLivenessTimer=hprRtpLivenessTimer, hprAnrCounterDisconTime=hprAnrCounterDisconTime, hprRtpShortReqTimeouts=hprRtpShortReqTimeouts, hprNceDefault=hprNceDefault, hprRtpStatusLocNceId=hprRtpStatusLocNceId, hprRtpLocTcid=hprRtpLocTcid, hprRtpMinSendRate=hprRtpMinSendRate, hprNceInstanceId=hprNceInstanceId)



#
# PySNMP MIB module NET-SNMP-MONITOR-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/NET-SNMP-MONITOR-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:22:39 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ConstraintsIntersection, ValueSizeConstraint, ConstraintsUnion, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ConstraintsUnion", "SingleValueConstraint")
( netSnmpModuleIDs, netSnmpObjects, ) = mibBuilder.importSymbols("NET-SNMP-MIB", "netSnmpModuleIDs", "netSnmpObjects")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( MibScalar, MibTable, MibTableRow, MibTableColumn, Counter64, NotificationType, Unsigned32, Counter32, ObjectIdentity, Integer32, Bits, TimeTicks, Gauge32, IpAddress, ModuleIdentity, iso, MibIdentifier, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter64", "NotificationType", "Unsigned32", "Counter32", "ObjectIdentity", "Integer32", "Bits", "TimeTicks", "Gauge32", "IpAddress", "ModuleIdentity", "iso", "MibIdentifier")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
netSnmpMonitorMIB = ModuleIdentity((1, 3, 6, 1, 4, 1, 8072, 3, 1, 3)).setRevisions(("2002-02-09 00:00",))
if mibBuilder.loadTexts: netSnmpMonitorMIB.setLastUpdated('200202090000Z')
if mibBuilder.loadTexts: netSnmpMonitorMIB.setOrganization('www.net-snmp.org')
if mibBuilder.loadTexts: netSnmpMonitorMIB.setContactInfo('postal:   Wes Hardaker\n                    P.O. Box 382\n                    Davis CA  95617\n\n          email:    net-snmp-coders@lists.sourceforge.net')
if mibBuilder.loadTexts: netSnmpMonitorMIB.setDescription('Configured elements of the system to monitor\n\t (XXX - ugh! - need a better description!)')
nsProcess = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 21))
nsDisk = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 22))
nsFile = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 23))
nsLog = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1, 24))
mibBuilder.exportSymbols("NET-SNMP-MONITOR-MIB", nsProcess=nsProcess, nsFile=nsFile, PYSNMP_MODULE_ID=netSnmpMonitorMIB, nsDisk=nsDisk, netSnmpMonitorMIB=netSnmpMonitorMIB, nsLog=nsLog)



#
# PySNMP MIB module NOTIFICATION-LOG-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/NOTIFICATION-LOG-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:22:51 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ConstraintsUnion, ValueRangeConstraint, ValueSizeConstraint, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ConstraintsUnion", "ValueRangeConstraint", "ValueSizeConstraint", "SingleValueConstraint")
( SnmpEngineID, SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpEngineID", "SnmpAdminString")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( Integer32, mib_2, MibIdentifier, Gauge32, IpAddress, TimeTicks, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, Counter64, NotificationType, ModuleIdentity, Opaque, Unsigned32, Counter32, iso, ObjectIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "mib-2", "MibIdentifier", "Gauge32", "IpAddress", "TimeTicks", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "Counter64", "NotificationType", "ModuleIdentity", "Opaque", "Unsigned32", "Counter32", "iso", "ObjectIdentity")
( TAddress, DisplayString, RowStatus, TDomain, DateAndTime, StorageType, TextualConvention, TimeStamp, ) = mibBuilder.importSymbols("SNMPv2-TC", "TAddress", "DisplayString", "RowStatus", "TDomain", "DateAndTime", "StorageType", "TextualConvention", "TimeStamp")
notificationLogMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 92)).setRevisions(("2000-11-27 00:00",))
if mibBuilder.loadTexts: notificationLogMIB.setLastUpdated('200011270000Z')
if mibBuilder.loadTexts: notificationLogMIB.setOrganization('IETF Distributed Management Working Group')
if mibBuilder.loadTexts: notificationLogMIB.setContactInfo('Ramanathan Kavasseri\n                    Cisco Systems, Inc.\n                    170 West Tasman Drive,\n                    San Jose CA 95134-1706.\n                    Phone: +1 408 527 2446\n                    Email: ramk@cisco.com')
if mibBuilder.loadTexts: notificationLogMIB.setDescription('The MIB module for logging SNMP Notifications, that is, Traps\n                    and Informs.')
notificationLogMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 92, 1))
nlmConfig = MibIdentifier((1, 3, 6, 1, 2, 1, 92, 1, 1))
nlmStats = MibIdentifier((1, 3, 6, 1, 2, 1, 92, 1, 2))
nlmLog = MibIdentifier((1, 3, 6, 1, 2, 1, 92, 1, 3))
nlmConfigGlobalEntryLimit = MibScalar((1, 3, 6, 1, 2, 1, 92, 1, 1, 1), Unsigned32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: nlmConfigGlobalEntryLimit.setDescription('The maximum number of notification entries that may be held\n                in nlmLogTable for all nlmLogNames added together.  A particular\n                setting does not guarantee that much data can be held.\n\n                If an application changes the limit while there are\n                Notifications in the log, the oldest Notifications MUST be\n                discarded to bring the log down to the new limit - thus the\n                value of nlmConfigGlobalEntryLimit MUST take precedence over\n                the values of nlmConfigGlobalAgeOut and nlmConfigLogEntryLimit,\n                even if the Notification being discarded has been present for\n                fewer minutes than the value of nlmConfigGlobalAgeOut, or if\n                the named log has fewer entries than that specified in\n                nlmConfigLogEntryLimit.\n\n                A value of 0 means no limit.\n\n                Please be aware that contention between multiple managers\n                trying to set this object to different values MAY affect the\n                reliability and completeness of data seen by each manager.\n                The default value is 0.')
nlmConfigGlobalAgeOut = MibScalar((1, 3, 6, 1, 2, 1, 92, 1, 1, 2), Unsigned32()).setUnits('minutes').setMaxAccess("readwrite")
if mibBuilder.loadTexts: nlmConfigGlobalAgeOut.setDescription('The number of minutes a Notification SHOULD be kept in a log\n                before it is automatically removed.\n\n                If an application changes the value of nlmConfigGlobalAgeOut,\n                Notifications older than the new time MAY be discarded to meet the\n                new time.\n\n                A value of 0 means no age out.\n\n                Please be aware that contention between multiple managers\n                trying to set this object to different values MAY affect the\n                reliability and completeness of data seen by each manager.\n                The default value is 1440(24 hours).')
nlmConfigLogTable = MibTable((1, 3, 6, 1, 2, 1, 92, 1, 1, 3), )
if mibBuilder.loadTexts: nlmConfigLogTable.setDescription('A table of logging control entries.')
nlmConfigLogEntry = MibTableRow((1, 3, 6, 1, 2, 1, 92, 1, 1, 3, 1), ).setIndexNames((0, "NOTIFICATION-LOG-MIB", "nlmLogName"))
if mibBuilder.loadTexts: nlmConfigLogEntry.setDescription("A logging control entry.  Depending on the entry's storage type\n                entries may be supplied by the system or created and deleted by\n                applications using nlmConfigLogEntryStatus.")
nlmLogName = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 1, 3, 1, 1), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)))
if mibBuilder.loadTexts: nlmLogName.setDescription('The name of the log.\n\n                An implementation may allow multiple named logs, up to some\n                implementation-specific limit (which may be none).  A\n                zero-length log name is reserved for creation and deletion by\n                the managed system, and MUST be used as the default log name by\n                systems that do not support named logs.')
nlmConfigLogFilterName = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 1, 3, 1, 2), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)).clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nlmConfigLogFilterName.setDescription('A value of snmpNotifyFilterProfileName as used as an index\n                into the snmpNotifyFilterTable in the SNMP Notification MIB,\n                specifying the locally or remotely originated Notifications\n                to be filtered out and not logged in this log.\n\n                A zero-length value or a name that does not identify an\n                existing entry in snmpNotifyFilterTable indicate no\n                Notifications are to be logged in this log.')
nlmConfigLogEntryLimit = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 1, 3, 1, 3), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nlmConfigLogEntryLimit.setDescription('The maximum number of notification entries that can be held in\n                nlmLogTable for this named log.  A particular setting does not\n                guarantee that that much data can be held.\n                \n                If an application changes the limit while there are\n                Notifications in the log, the oldest Notifications are discarded\n                to bring the log down to the new limit.\n                A value of 0 indicates no limit.\n                \n                Please be aware that contention between multiple managers\n                trying to set this object to different values MAY affect the\n                reliability and completeness of data seen by each manager.')
nlmConfigLogAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 1, 3, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2),)).clone('enabled')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nlmConfigLogAdminStatus.setDescription("Control to enable or disable the log without otherwise\n                disturbing the log's entry.\n                \n                Please be aware that contention between multiple managers\n                trying to set this object to different values MAY affect the\n                reliability and completeness of data seen by each manager.")
nlmConfigLogOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 1, 3, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("disabled", 1), ("operational", 2), ("noFilter", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmConfigLogOperStatus.setDescription('The operational status of this log:\n                \n                  disabled  administratively disabled\n                \n                  operational    administratively enabled and working\n                \n                  noFilter  administratively enabled but either\n                            nlmConfigLogFilterName is zero length\n                            or does not name an existing entry in\n                            snmpNotifyFilterTable')
nlmConfigLogStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 1, 3, 1, 6), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nlmConfigLogStorageType.setDescription('The storage type of this conceptual row.')
nlmConfigLogEntryStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 1, 3, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: nlmConfigLogEntryStatus.setDescription("Control for creating and deleting entries.  Entries may be\n                modified while active.\n                \n                For non-null-named logs, the managed system records the security\n                credentials from the request that sets nlmConfigLogStatus\n                to 'active' and uses that identity to apply access control to\n                the objects in the Notification to decide if that Notification\n                may be logged.")
nlmStatsGlobalNotificationsLogged = MibScalar((1, 3, 6, 1, 2, 1, 92, 1, 2, 1), Counter32()).setUnits('notifications').setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmStatsGlobalNotificationsLogged.setDescription('The number of Notifications put into the nlmLogTable.  This\n                counts a Notification once for each log entry, so a Notification\n                put into multiple logs is counted multiple times.')
nlmStatsGlobalNotificationsBumped = MibScalar((1, 3, 6, 1, 2, 1, 92, 1, 2, 2), Counter32()).setUnits('notifications').setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmStatsGlobalNotificationsBumped.setDescription('The number of log entries discarded to make room for a new entry\n                due to lack of resources or the value of nlmConfigGlobalEntryLimit\n                or nlmConfigLogEntryLimit.  This does not include entries discarded\n                due to the value of nlmConfigGlobalAgeOut.')
nlmStatsLogTable = MibTable((1, 3, 6, 1, 2, 1, 92, 1, 2, 3), )
if mibBuilder.loadTexts: nlmStatsLogTable.setDescription('A table of Notification log statistics entries.')
nlmStatsLogEntry = MibTableRow((1, 3, 6, 1, 2, 1, 92, 1, 2, 3, 1), )
nlmConfigLogEntry.registerAugmentions(("NOTIFICATION-LOG-MIB", "nlmStatsLogEntry"))
nlmStatsLogEntry.setIndexNames(*nlmConfigLogEntry.getIndexNames())
if mibBuilder.loadTexts: nlmStatsLogEntry.setDescription('A Notification log statistics entry.')
nlmStatsLogNotificationsLogged = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 2, 3, 1, 1), Counter32()).setUnits('notifications').setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmStatsLogNotificationsLogged.setDescription('The number of Notifications put in this named log.')
nlmStatsLogNotificationsBumped = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 2, 3, 1, 2), Counter32()).setUnits('notifications').setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmStatsLogNotificationsBumped.setDescription('The number of log entries discarded from this named log to make\n                room for a new entry due to lack of resources or the value of\n                nlmConfigGlobalEntryLimit or nlmConfigLogEntryLimit.  This does not\n                include entries discarded due to the value of\n                nlmConfigGlobalAgeOut.')
nlmLogTable = MibTable((1, 3, 6, 1, 2, 1, 92, 1, 3, 1), )
if mibBuilder.loadTexts: nlmLogTable.setDescription('A table of Notification log entries.\n                \n                It is an implementation-specific matter whether entries in this\n                table are preserved across initializations of the management\n                system.  In general one would expect that they are not.\n                \n                Note that keeping entries across initializations of the\n                management system leads to some confusion with counters and\n                TimeStamps, since both of those are based on sysUpTime, which\n                resets on management initialization.  In this situation,\n                counters apply only after the reset and nlmLogTime for entries\n                made before the reset MUST be set to 0.')
nlmLogEntry = MibTableRow((1, 3, 6, 1, 2, 1, 92, 1, 3, 1, 1), ).setIndexNames((0, "NOTIFICATION-LOG-MIB", "nlmLogName"), (0, "NOTIFICATION-LOG-MIB", "nlmLogIndex"))
if mibBuilder.loadTexts: nlmLogEntry.setDescription('A Notification log entry.\n                \n                Entries appear in this table when Notifications occur and pass\n                filtering by nlmConfigLogFilterName and access control.  They are\n                removed to make way for new entries due to lack of resources or\n                the values of nlmConfigGlobalEntryLimit, nlmConfigGlobalAgeOut, or\n                nlmConfigLogEntryLimit.\n                \n                If adding an entry would exceed nlmConfigGlobalEntryLimit or system\n                resources in general, the oldest entry in any log SHOULD be removed\n                to make room for the new one.\n                \n                If adding an entry would exceed nlmConfigLogEntryLimit the oldest\n                entry in that log SHOULD be removed to make room for the new one.\n                \n                Before the managed system puts a locally-generated Notification\n                into a non-null-named log it assures that the creator of the log\n                has access to the information in the Notification.  If not it\n                does not log that Notification in that log.')
nlmLogIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: nlmLogIndex.setDescription('A monotonically increasing integer for the sole purpose of\n                indexing entries within the named log.  When it reaches the\n                maximum value, an extremely unlikely event, the agent wraps the\n                value back to 1.')
nlmLogTime = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 1, 1, 2), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogTime.setDescription('The value of sysUpTime when the entry was placed in the log. If\n                the entry occurred before the most recent management system\n                initialization this object value MUST be set to zero.')
nlmLogDateAndTime = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 1, 1, 3), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogDateAndTime.setDescription('The local date and time when the entry was logged, instantiated\n                only by systems that have date and time capability.')
nlmLogEngineID = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 1, 1, 4), SnmpEngineID()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogEngineID.setDescription('The identification of the SNMP engine at which the Notification\n                originated.\n                \n                If the log can contain Notifications from only one engine\n                or the Trap is in SNMPv1 format, this object is a zero-length\n                string.')
nlmLogEngineTAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 1, 1, 5), TAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogEngineTAddress.setDescription('The transport service address of the SNMP engine from which the\n                Notification was received, formatted according to the corresponding\n                value of nlmLogEngineTDomain. This is used to identify the source\n                of an SNMPv1 trap, since an nlmLogEngineId cannot be extracted\n                from the SNMPv1 trap pdu.\n                \n                This object MUST always be instantiated, even if the log\n                can contain Notifications from only one engine.\n                \n                Please be aware that the nlmLogEngineTAddress may not uniquely\n                identify the SNMP engine from which the Notification was received.\n                For example, if an SNMP engine uses DHCP or NAT to obtain\n                ip addresses, the address it uses may be shared with other\n                network devices, and hence will not uniquely identify the\n                SNMP engine.')
nlmLogEngineTDomain = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 1, 1, 6), TDomain()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogEngineTDomain.setDescription('Indicates the kind of transport service by which a Notification\n                was received from an SNMP engine. nlmLogEngineTAddress contains\n                the transport service address of the SNMP engine from which\n                this Notification was received.\n                \n                Possible values for this object are presently found in the\n                Transport Mappings for SNMPv2 document (RFC 1906 [8]).')
nlmLogContextEngineID = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 1, 1, 7), SnmpEngineID()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogContextEngineID.setDescription('If the Notification was received in a protocol which has a\n                contextEngineID element like SNMPv3, this object has that value.\n                Otherwise its value is a zero-length string.')
nlmLogContextName = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 1, 1, 8), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogContextName.setDescription('The name of the SNMP MIB context from which the Notification came.\n                For SNMPv1 Traps this is the community string from the Trap.')
nlmLogNotificationID = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 1, 1, 9), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogNotificationID.setDescription('The NOTIFICATION-TYPE object identifier of the Notification that\n                occurred.')
nlmLogVariableTable = MibTable((1, 3, 6, 1, 2, 1, 92, 1, 3, 2), )
if mibBuilder.loadTexts: nlmLogVariableTable.setDescription('A table of variables to go with Notification log entries.')
nlmLogVariableEntry = MibTableRow((1, 3, 6, 1, 2, 1, 92, 1, 3, 2, 1), ).setIndexNames((0, "NOTIFICATION-LOG-MIB", "nlmLogName"), (0, "NOTIFICATION-LOG-MIB", "nlmLogIndex"), (0, "NOTIFICATION-LOG-MIB", "nlmLogVariableIndex"))
if mibBuilder.loadTexts: nlmLogVariableEntry.setDescription('A Notification log entry variable.\n                \n                Entries appear in this table when there are variables in\n                the varbind list of a Notification in nlmLogTable.')
nlmLogVariableIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 2, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: nlmLogVariableIndex.setDescription('A monotonically increasing integer, starting at 1 for a given\n                nlmLogIndex, for indexing variables within the logged\n                Notification.')
nlmLogVariableID = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 2, 1, 2), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogVariableID.setDescription("The variable's object identifier.")
nlmLogVariableValueType = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 2, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9,))).clone(namedValues=NamedValues(("counter32", 1), ("unsigned32", 2), ("timeTicks", 3), ("integer32", 4), ("ipAddress", 5), ("octetString", 6), ("objectId", 7), ("counter64", 8), ("opaque", 9),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogVariableValueType.setDescription('The type of the value.  One and only one of the value\n                objects that follow must be instantiated, based on this type.')
nlmLogVariableCounter32Val = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 2, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogVariableCounter32Val.setDescription("The value when nlmLogVariableType is 'counter32'.")
nlmLogVariableUnsigned32Val = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 2, 1, 5), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogVariableUnsigned32Val.setDescription("The value when nlmLogVariableType is 'unsigned32'.")
nlmLogVariableTimeTicksVal = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 2, 1, 6), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogVariableTimeTicksVal.setDescription("The value when nlmLogVariableType is 'timeTicks'.")
nlmLogVariableInteger32Val = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 2, 1, 7), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogVariableInteger32Val.setDescription("The value when nlmLogVariableType is 'integer32'.")
nlmLogVariableOctetStringVal = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 2, 1, 8), OctetString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogVariableOctetStringVal.setDescription("The value when nlmLogVariableType is 'octetString'.")
nlmLogVariableIpAddressVal = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 2, 1, 9), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogVariableIpAddressVal.setDescription("The value when nlmLogVariableType is 'ipAddress'.\n                Although this seems to be unfriendly for IPv6, we\n                have to recognize that there are a number of older\n                MIBs that do contain an IPv4 format address, known\n                as IpAddress.\n                \n                IPv6 addresses are represented using TAddress or\n                InetAddress, and so the underlying datatype is\n                OCTET STRING, and their value would be stored in\n                the nlmLogVariableOctetStringVal column.")
nlmLogVariableOidVal = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 2, 1, 10), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogVariableOidVal.setDescription("The value when nlmLogVariableType is 'objectId'.")
nlmLogVariableCounter64Val = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 2, 1, 11), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogVariableCounter64Val.setDescription("The value when nlmLogVariableType is 'counter64'.")
nlmLogVariableOpaqueVal = MibTableColumn((1, 3, 6, 1, 2, 1, 92, 1, 3, 2, 1, 12), Opaque()).setMaxAccess("readonly")
if mibBuilder.loadTexts: nlmLogVariableOpaqueVal.setDescription("The value when nlmLogVariableType is 'opaque'.")
notificationLogMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 92, 3))
notificationLogMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 92, 3, 1))
notificationLogMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 92, 3, 2))
notificationLogMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 92, 3, 1, 1)).setObjects(*(("NOTIFICATION-LOG-MIB", "notificationLogConfigGroup"), ("NOTIFICATION-LOG-MIB", "notificationLogStatsGroup"), ("NOTIFICATION-LOG-MIB", "notificationLogLogGroup"),))
if mibBuilder.loadTexts: notificationLogMIBCompliance.setDescription('The compliance statement for entities which implement\n                the Notification Log MIB.')
notificationLogConfigGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 92, 3, 2, 1)).setObjects(*(("NOTIFICATION-LOG-MIB", "nlmConfigGlobalEntryLimit"), ("NOTIFICATION-LOG-MIB", "nlmConfigGlobalAgeOut"), ("NOTIFICATION-LOG-MIB", "nlmConfigLogFilterName"), ("NOTIFICATION-LOG-MIB", "nlmConfigLogEntryLimit"), ("NOTIFICATION-LOG-MIB", "nlmConfigLogAdminStatus"), ("NOTIFICATION-LOG-MIB", "nlmConfigLogOperStatus"), ("NOTIFICATION-LOG-MIB", "nlmConfigLogStorageType"), ("NOTIFICATION-LOG-MIB", "nlmConfigLogEntryStatus"),))
if mibBuilder.loadTexts: notificationLogConfigGroup.setDescription('Notification log configuration management.')
notificationLogStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 92, 3, 2, 2)).setObjects(*(("NOTIFICATION-LOG-MIB", "nlmStatsGlobalNotificationsLogged"), ("NOTIFICATION-LOG-MIB", "nlmStatsGlobalNotificationsBumped"), ("NOTIFICATION-LOG-MIB", "nlmStatsLogNotificationsLogged"), ("NOTIFICATION-LOG-MIB", "nlmStatsLogNotificationsBumped"),))
if mibBuilder.loadTexts: notificationLogStatsGroup.setDescription('Notification log statistics.')
notificationLogLogGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 92, 3, 2, 3)).setObjects(*(("NOTIFICATION-LOG-MIB", "nlmLogTime"), ("NOTIFICATION-LOG-MIB", "nlmLogEngineID"), ("NOTIFICATION-LOG-MIB", "nlmLogEngineTAddress"), ("NOTIFICATION-LOG-MIB", "nlmLogEngineTDomain"), ("NOTIFICATION-LOG-MIB", "nlmLogContextEngineID"), ("NOTIFICATION-LOG-MIB", "nlmLogContextName"), ("NOTIFICATION-LOG-MIB", "nlmLogNotificationID"), ("NOTIFICATION-LOG-MIB", "nlmLogVariableID"), ("NOTIFICATION-LOG-MIB", "nlmLogVariableValueType"), ("NOTIFICATION-LOG-MIB", "nlmLogVariableCounter32Val"), ("NOTIFICATION-LOG-MIB", "nlmLogVariableUnsigned32Val"), ("NOTIFICATION-LOG-MIB", "nlmLogVariableTimeTicksVal"), ("NOTIFICATION-LOG-MIB", "nlmLogVariableInteger32Val"), ("NOTIFICATION-LOG-MIB", "nlmLogVariableOctetStringVal"), ("NOTIFICATION-LOG-MIB", "nlmLogVariableIpAddressVal"), ("NOTIFICATION-LOG-MIB", "nlmLogVariableOidVal"), ("NOTIFICATION-LOG-MIB", "nlmLogVariableCounter64Val"), ("NOTIFICATION-LOG-MIB", "nlmLogVariableOpaqueVal"),))
if mibBuilder.loadTexts: notificationLogLogGroup.setDescription('Notification log data.')
notificationLogDateGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 92, 3, 2, 4)).setObjects(*(("NOTIFICATION-LOG-MIB", "nlmLogDateAndTime"),))
if mibBuilder.loadTexts: notificationLogDateGroup.setDescription('Conditionally mandatory notification log data.\n                This group is mandatory on systems that keep wall\n                clock date and time and should not be implemented\n                on systems that do not have a wall clock date.')
mibBuilder.exportSymbols("NOTIFICATION-LOG-MIB", nlmStats=nlmStats, notificationLogStatsGroup=notificationLogStatsGroup, notificationLogDateGroup=notificationLogDateGroup, nlmLogVariableOpaqueVal=nlmLogVariableOpaqueVal, nlmStatsLogNotificationsBumped=nlmStatsLogNotificationsBumped, nlmConfigLogTable=nlmConfigLogTable, nlmStatsLogEntry=nlmStatsLogEntry, nlmStatsGlobalNotificationsBumped=nlmStatsGlobalNotificationsBumped, nlmLogEngineTDomain=nlmLogEngineTDomain, nlmLogVariableID=nlmLogVariableID, notificationLogMIBCompliances=notificationLogMIBCompliances, nlmLogVariableEntry=nlmLogVariableEntry, notificationLogLogGroup=notificationLogLogGroup, nlmConfigGlobalEntryLimit=nlmConfigGlobalEntryLimit, nlmLogVariableTimeTicksVal=nlmLogVariableTimeTicksVal, nlmConfigLogAdminStatus=nlmConfigLogAdminStatus, nlmLogVariableCounter64Val=nlmLogVariableCounter64Val, nlmConfigLogEntry=nlmConfigLogEntry, nlmLogTable=nlmLogTable, nlmLogEngineID=nlmLogEngineID, nlmLogVariableOctetStringVal=nlmLogVariableOctetStringVal, nlmLog=nlmLog, PYSNMP_MODULE_ID=notificationLogMIB, nlmLogContextEngineID=nlmLogContextEngineID, nlmConfigLogFilterName=nlmConfigLogFilterName, nlmConfigLogStorageType=nlmConfigLogStorageType, nlmLogIndex=nlmLogIndex, nlmStatsLogTable=nlmStatsLogTable, notificationLogMIB=notificationLogMIB, nlmLogEntry=nlmLogEntry, nlmConfigLogOperStatus=nlmConfigLogOperStatus, notificationLogMIBObjects=notificationLogMIBObjects, nlmLogTime=nlmLogTime, nlmLogVariableOidVal=nlmLogVariableOidVal, notificationLogMIBCompliance=notificationLogMIBCompliance, nlmStatsLogNotificationsLogged=nlmStatsLogNotificationsLogged, nlmConfigLogEntryStatus=nlmConfigLogEntryStatus, nlmLogContextName=nlmLogContextName, nlmLogVariableTable=nlmLogVariableTable, nlmLogVariableCounter32Val=nlmLogVariableCounter32Val, nlmLogVariableIndex=nlmLogVariableIndex, notificationLogMIBGroups=notificationLogMIBGroups, notificationLogConfigGroup=notificationLogConfigGroup, nlmLogVariableInteger32Val=nlmLogVariableInteger32Val, nlmLogVariableValueType=nlmLogVariableValueType, nlmLogNotificationID=nlmLogNotificationID, nlmConfigLogEntryLimit=nlmConfigLogEntryLimit, nlmConfig=nlmConfig, nlmLogVariableIpAddressVal=nlmLogVariableIpAddressVal, nlmLogVariableUnsigned32Val=nlmLogVariableUnsigned32Val, notificationLogMIBConformance=notificationLogMIBConformance, nlmConfigGlobalAgeOut=nlmConfigGlobalAgeOut, nlmStatsGlobalNotificationsLogged=nlmStatsGlobalNotificationsLogged, nlmLogEngineTAddress=nlmLogEngineTAddress, nlmLogName=nlmLogName, nlmLogDateAndTime=nlmLogDateAndTime)
